@@ -20,7 +20,7 @@ from calculate.core.server.func import Action, Tasks
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.utils.files import FilesError, listDirectory
 from calculate.lib.utils.mount import isMount
-from calculate.desktop.desktop import DesktopError
+from ..desktop import DesktopError
 from calculate.lib.cl_template import TemplatesError
 
 _ = lambda x: x
